/**
 * Format sql result.
 * @function _format
 * @private
 */

"use strict";

/** @lends _format */
function _format(tableName, data) {
    if (!data) {
        return;
    }
    if (Array.isArray(data)) {
        return data.map(function (data) {
            return _format(tableName, data);
        });
    }
    var formatted = {};
    Object.keys(data).forEach(function (key) {
        var val = data[key],
            names = key.split(/\./).filter(function (name) {
                return !!name;
            });
        if (names.length == 1) {
            formatted[key.replace(/^\./, '')] = data[key];
            return;
        }
        var namespace = names[0] && names[0].toLowerCase(),
            col = names[1] && names[1].toLowerCase();
        var hasNameSpace = namespace && (namespace != tableName.toLowerCase());
        if (hasNameSpace) {
            formatted[namespace] = formatted[namespace] || {};
            formatted[namespace][col] = val;
        } else {
            formatted[col] = val;
        }
    });
    return formatted;
}

module.exports = _format;
