/**
 * Test for driver.
 * Runs with mocha.
 */

"use strict";

var testDbConfig = require('../ci/configs/test_db_config'),
    mysql = require('mysql'),
    extend = require('extend'),
    assert = require('assert'),
    setupTestDb = require('../ci/helpers/setup_test_db'),
    async = require('async'),
    driver = require('../lib/driver');

var connectConfig = extend({}, testDbConfig, {
    database: 'mysqldriver_test'
});
var connection;
describe('driver', function () {
    before(function (done) {
        setupTestDb(function (err) {

            connection = mysql.createConnection(connectConfig);
            connection.connect(function () {
                done();
            });
        });
    });
    after(function (done) {
        connection.end(function () {
            done();
        });
    });

    it('Crud with resource.', function (done) {
        var connected = driver(connectConfig);
        connected.connect(function () {
            var resource = connected.resource('TEST_SHOP', {
                idKey: 'id'
            });
            var created;
            async.series([
                function (callback) {
                    resource.create({
                        article: 124,
                        dealer: 'foo',
                        price: 389
                    }, function (err, result) {
                        assert.ifError(err);
                        created = result.data;
                        assert.equal(result.success, true);
                        assert.equal(result.data.price, 389);
                        callback(err);
                    });
                },
                function (callback) {
                    resource.one(created.id, function (err, data) {
                        assert.ifError(err);
                        assert.equal(data.price, 389);
                        callback(err);
                    });
                },
                function (callback) {
                    resource.update(created.id, {price: 400}, function (err, result) {
                        assert.ifError(err);
                        assert.equal(result.data.price, 400);
                        callback(err);
                    });
                },
                function (callback) {
                    resource.updateBulk({id: [created.id]}, {price: 440}, function (err, result) {
                        assert.ifError(err);
                        assert.equal(result.data.length, 1);
                        assert.equal(result.data[0].price, 440);
                        callback(err);
                    });
                },
                function (callback) {
                    resource.list({}, function (err, result) {
                        assert.ifError(err);
                        assert.ok(result.length > 0);
                        callback(err);
                    });
                },
                function (callback) {
                    resource.count({}, function (err, count) {
                        assert.ifError(err);
                        assert.ok(count > 0);
                        callback(err);
                    });
                },
                function (callback) {
                    resource.destroy(created.id, function (err, result) {
                        assert.ifError(err);
                        assert.equal(result.data.price, 440);
                        resource.one(created.id, function (err, data) {
                            assert.ifError(err);
                            assert.ifError(data);
                            callback(err);
                        });
                    });
                },
                function (callback) {
                    resource.destroyBulk({}, function (err, result) {
                        assert.ifError(err);
                        resource.one(created.id, function (err, data) {
                            assert.ifError(err);
                            assert.ifError(data);
                            callback(err);
                        });
                    });
                }
            ], function (err) {
                assert.ifError(err);
                connected.disconnect(function () {
                    done();
                });
            });
        });

    });


});
